class VBANCMDError(Exception):
    """general errors"""

    pass
